@@ -182,10 +182,12 @@ test_that("useDynLib doesn't quote if comma present", {
 })
 
 test_that("empty NAMESPACE generates zero-length vector", {
-  base_path <- normalizePath("empty")
-  parsed <- parse_package(base_path, source_package, registry = list())
+  base_path <- test_path("empty")
 
-  results <- roclet_process(namespace_roclet(), parsed, base_path)
+  env <- pkgload::load_all(base_path)$env
+  blocks <- parse_package(base_path, env = env, registry = list())
+
+  results <- roclet_process(namespace_roclet(), blocks, env = env, base_path)
   expect_equal(results, character())
 })
 
@@ -212,3 +214,81 @@ test_that("rawNamespace inserted unchanged", {
   expect_equal(out, "xyz\n  abc")
 })
 
+
+# @evalNamespace ----------------------------------------------------------
+
+test_that("evalNamespace generates warning when code is invalid", {
+  expect_warning(
+    roc_proc_text(namespace_roclet(), "
+      #' @evalNamespace a +
+      #' @name a
+      #' @title a
+      NULL"),
+    "code failed to parse"  # Message generated by tag_code
+  )
+})
+
+test_that("evalNamespace generates warning when code raises error", {
+  expect_warning(
+    roc_proc_text(namespace_roclet(), "
+      #' @evalNamespace stop('!')
+      #' @name a
+      #' @title a
+      NULL"),
+    "@evalNamespace failed with error"  # From block_eval
+  )
+})
+
+test_that("evalNamespace generates warning when code doesn't eval to string", {
+  # Not character
+  expect_warning(
+    roc_proc_text(namespace_roclet(), "
+      z <- 10
+      #' @evalNamespace z * 2
+      #' @name a
+      #' @title a
+      NULL"),
+    "@evalNamespace did not evaluate to a string"  # From block_eval
+  )
+
+  # NA_character_ not allowed
+  expect_warning(
+    roc_proc_text(namespace_roclet(), "
+      nms <- NA_character_
+      #' @evalNamespace nms
+      #' @name a
+      #' @title a
+      NULL"),
+    "@evalNamespace result contained NA"  # From block_eval
+  )
+})
+
+test_that("evalNamespace code is inserted when its value is a string", {
+  out1 <- roc_proc_text(namespace_roclet(), "
+    nms <- paste(letters[1:3], collapse = ',')
+    #' @evalNamespace sprintf('export(%s)', nms)
+    #' @name a
+    #' @title a
+    NULL")
+  out2 <- roc_proc_text(namespace_roclet(), "
+    nms <- paste(letters[1:3], collapse = ',')
+    #' @evalNamespace sprintf('export(%s)',
+    #'                        nms)
+    #' @name a
+    #' @title a
+    NULL")
+
+  expect_equal(out1, "export(a,b,c)")
+  expect_equal(out2, "export(a,b,c)")
+})
+
+test_that("evalNamspace can yield a vector", {
+  out <- roc_proc_text(namespace_roclet(), "
+    nms <- letters[1:2]
+    #' @evalNamespace paste0('export(', nms, ')')
+    #' @name a
+    #' @title a
+    NULL")
+
+  expect_equal(out, c("export(a)", "export(b)"))
+})
