@@ -38,6 +38,25 @@ test_that("can use NULL to suppress default aliases", {
   expect_equal(get_tag(out, "alias")$values, character())
 })
 
+test_that("aliases get deduplicated", {
+  out <- roc_proc_text(rd_roclet(), "
+    #' @aliases a b a
+    #' @title a
+    #' @name a
+    NULL")[[1]]
+
+  expect_equal(format(get_tag(out, "alias")), c("\\alias{a}", "\\alias{b}"))
+})
+
+test_that("aliases get deduplicated with defaults suppressed", {
+  out <- roc_proc_text(rd_roclet(), "
+    #' @aliases NULL b c b
+    #' @title a
+    #' @name a
+    NULL")[[1]]
+
+  expect_equal(format(get_tag(out, "alias")), c("\\alias{b}", "\\alias{c}"))
+})
 
 test_that("refclass with assignment gets both aliases", {
   out <- roc_proc_text(rd_roclet(), "
@@ -45,7 +64,7 @@ test_that("refclass with assignment gets both aliases", {
     B3 <- setRefClass('B3')
   ")[[1]]
 
-  expect_equal(get_tag(out, "alias")$value, c("B3-class", "B3"))
+  expect_equal(get_tag(out, "alias")$values, c("B3-class", "B3"))
 })
 
 
@@ -55,5 +74,5 @@ test_that("refclass gets -class alias", {
     setRefClass('B2')
   ")[[1]]
 
-  expect_equal(get_tag(out, "alias")$value, "B2-class")
+  expect_equal(get_tag(out, "alias")$values, "B2-class")
 })
